Module parser

Module parser 

Structs

Parse
Result of parsing an Ink source file.
ParseError
A parse error with a message and the source range it points at.

Functions

parse
Parse an Ink source string into a lossless CST.
parse_with_cache
Parse with a shared rowan::NodeCache for green-node interning.